# Deimos - Shared Module

Packet formats and byte-serialization for the Deimos data acquisition ecosystem.

See the [project readme](https://github.com/deimoscontrols/deimos/blob/main/README.md) for contact details as well as commentary about
the goals and state of the project.

This library is shared with both the peripheral firmware and the control program so that critical
data structures and constants maintain parity at all times.
